@@ -7,7 +7,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 from sklearn.preprocessing import StandardScaler
 from math import pi
-from FPLUnderStats import GetStats
+from fpl_analytics.FPLUnderStats import GetStats
 
 class FPLAnalytics:
     log_dir = 'logs'
